bayespy.nodes.GaussianARD.initialize_from_mean_and_covariance
=============================================================

.. currentmodule:: bayespy.nodes

.. automethod:: GaussianARD.initialize_from_mean_and_covariance